#Script to create Fig.1 of Monier et al. manuscript "Drosophila glue: a promising model for bioadhesion"
#Distribution of Drosophila glue papers by year of publication and research topic


#install.packages("cowplot")
#install.packages("dplyr")
#install.packages("ggplot2")
library(gplots)
library(ggplot2)
library(dplyr)
library(cowplot)

#Load data file containing the list of publications (retrieved from PubMed on 7 June 2022)
setwd("/Users/courtier/Documents/mon-labo/membres/Manon/Drosophila-glue-review")
ArticlesTable=read.csv("Drosophila_glue_articles.csv",header=T,sep=",",stringsAsFactors=FALSE)
View(ArticlesTable)
ArticlesTable=as.data.frame(ArticlesTable)
nrow(ArticlesTable)
#We searched for "Drosophila glue" in PubMed on 7th June 2022 and retrieved 152 research articles (Table S1). 

#Remove irrelevant articles
ArticlesTable=ArticlesTable[ArticlesTable$Topic!="irrelevant",]
View(ArticlesTable)
nrow(ArticlesTable)
#Among them, 32 were not relevant and 120 dealt with the glue produced by Drosophila larvae before entering metamorphosis. 

#Check all topic categories and the distribution of papers
View(table(ArticlesTable$Topic))
#We attributed to each article one of the following research topics: glue gene expression (70 articles),
#glue gene identification (16 articles), glue secretion (12 articles), glue of other Drosophila species (12 articles),
#salivary gland physiology (7 articles), glue ultrastructure and adhesion (3 articles).



#Drawing of Figure 1, distribution of publications by year and research topic

#Creation of a blank plot
blankPlot=ggplot()+geom_blank(aes(1,1))+
  theme(
    plot.background = element_blank(), 
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(), 
    panel.border = element_blank(),
    panel.background = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_blank(), 
    axis.text.y = element_blank(),
    axis.ticks = element_blank(),
    axis.line = element_blank()
  )

tA=ArticlesTable[ArticlesTable$Topic=="glue gene expression",]
View(tA)

panelA <- ggplot(tA, aes(x = Publication_Year),
                 ylim=c(0,20)) + 
  geom_histogram(binwidth = 2, color = "white", fill = "#1B9E77") +
  scale_x_continuous(limits=c(1975,2021), breaks = c(1976, 1980, 1984, 1988, 1992, 1996, 2000, 2004, 2008, 2012, 2016, 2020))+
  scale_y_continuous(expand = c(0, 0),limits=c(0,15),name ="\nNumber of \n publications")+
  theme(
    # Hide panel borders and remove grid lines
    panel.background = element_blank(),
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    # Change axis line
    axis.line = element_line(colour = "black"),
    axis.title.x=element_blank(),
    axis.text.x = element_text(size=8),
    axis.text.y = element_text(size=8),
    axis.title.y = element_text(size=8))+
  annotate(geom="text", x=2004, y=10, label="Glue gene expression",
             color="black", size=3)
panelA

tB=ArticlesTable[ArticlesTable$Topic=="glue secretion",]
#View(tB)
panelB <- ggplot(tB, aes(x = Publication_Year),
                 ylim=c(0,20)) + 
  geom_histogram(binwidth = 2, color = "white", fill = "#D95F02") +
  scale_x_continuous(limits=c(1975,2021), breaks = c(1976, 1980, 1984, 1988, 1992, 1996, 2000, 2004, 2008, 2012, 2016, 2020))+
  scale_y_continuous(expand = c(0, 0),limits=c(0,5),breaks = c(0,1,2,3,4,5),name ="\nNumber of \n publications")+
  theme(
    # Hide panel borders and remove grid lines
    panel.background = element_blank(),
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    # Change axis line
    axis.line = element_line(colour = "black"),
    axis.title.x=element_blank(),
    axis.text.x = element_text(size=8),
    axis.text.y = element_text(size=8),
    axis.title.y = element_text(size=8))+
  annotate(geom="text", x=2004, y=3.8, label="Glue secretion",
           color="black", size=3)
panelB

tC=ArticlesTable[ArticlesTable$Topic=="glue gene identification",]
#View(tC)
panelC <- ggplot(tC, aes(x = Publication_Year),
                 ylim=c(0,20)) + 
  geom_histogram(binwidth = 2, color = "white", fill = "#7570B3") +
  scale_x_continuous(limits=c(1975,2021), breaks = c(1976, 1980, 1984, 1988, 1992, 1996, 2000, 2004, 2008, 2012, 2016, 2020))+
  scale_y_continuous(expand = c(0, 0),limits=c(0,5),breaks = c(0,1,2,3,4,5),name ="\nNumber of \n publications")+
  theme(
    # Hide panel borders and remove grid lines
    panel.background = element_blank(),
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    # Change axis line
    axis.line = element_line(colour = "black"),
    axis.title.x=element_blank(),
    axis.text.x = element_text(size=8),
    axis.text.y = element_text(size=8),
    axis.title.y = element_text(size=8))+
  annotate(geom="text", x=2004, y=3.8, label="Glue gene identification",
           color="black", size=3)

panelC

tD=ArticlesTable[ArticlesTable$Topic=="glue of other Drosophila species",]
#View(tD)
panelD <- ggplot(tD, aes(x = Publication_Year),
                 ylim=c(0,20)) + 
  geom_histogram(binwidth = 2, color = "white", fill = "#E7298A") +
  scale_x_continuous(limits=c(1975,2021), breaks = c(1976, 1980, 1984, 1988, 1992, 1996, 2000, 2004, 2008, 2012, 2016, 2020))+
  scale_y_continuous(expand = c(0, 0),limits=c(0,5),breaks = c(0,1,2,3,4,5),name ="\nNumber of \n publications")+
  theme(
    # Hide panel borders and remove grid lines
    panel.background = element_blank(),
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    # Change axis line
    axis.line = element_line(colour = "black"),
    axis.title.x=element_blank(),
    axis.text.x = element_text(size=8),
    axis.text.y = element_text(size=8),
    axis.title.y = element_text(size=8))+
  annotate(geom="text", x=2004, y=3.8, label="Glue of other Drosophila species",
           color="black", size=3)
panelD

tE=ArticlesTable[ArticlesTable$Topic=="salivary gland physiology",]
#View(tE)
panelE <- ggplot(tE, aes(x = Publication_Year),
                 ylim=c(0,20)) + 
  geom_histogram(binwidth = 2, color = "white", fill = "#66A61E") +
  scale_x_continuous(limits=c(1975,2021), breaks = c(1976, 1980, 1984, 1988, 1992, 1996, 2000, 2004, 2008, 2012, 2016, 2020))+
  scale_y_continuous(expand = c(0, 0),limits=c(0,5),breaks = c(0,1,2,3,4,5),name ="\nNumber of \n publications")+
  theme(
    # Hide panel borders and remove grid lines
    panel.background = element_blank(),
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    # Change axis line
    axis.line = element_line(colour = "black"),
    axis.title.x=element_blank(),
    axis.text.x = element_text(size=8),
    axis.text.y = element_text(size=8),
    axis.title.y = element_text(size=8))+
  annotate(geom="text", x=2004, y=3.8, label="Salivary gland physiology",
           color="black", size=3)
panelE

tF=ArticlesTable[ArticlesTable$Topic=="glue ultrastructure and adhesion",]
#View(tF)
panelF <- ggplot(tF, aes(x = Publication_Year),
                 ylim=c(0,20)) + 
  geom_histogram(binwidth = 2, color = "white", fill = "#666666") +
  scale_x_continuous(limits=c(1975,2021), breaks = c(1976, 1980, 1984, 1988, 1992, 1996, 2000, 2004, 2008, 2012, 2016, 2020))+
  scale_y_continuous(expand = c(0, 0),limits=c(0,5),breaks = c(0,1,2,3,4,5),name ="\nNumber of \n publications")+
  theme(
    # Hide panel borders and remove grid lines
    panel.background = element_blank(),
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    # Change axis line
    axis.line = element_line(colour = "black"),
    axis.title.x=element_blank(),
    axis.text.x = element_text(size=8),
    axis.text.y = element_text(size=8),
    axis.title.y = element_text(size=8))+
  annotate(geom="text", x=2004, y=3.8, label="Glue ultrastructure and adhesion",
           color="black", size=3)
panelF
  
tAB=rbind(tA,tB)
#View(tAB)

fig=plot_grid(panelA,blankPlot,panelB,blankPlot,panelC,blankPlot,panelD,blankPlot,panelE,blankPlot,panelF,blankPlot,blankPlot,blankPlot,
              labels = c("A","","B","","C","","D","","E","","F","","",""),
              ncol = 2, nrow = 7,rel_heights = c(2.3,1,1,1,1,1,4.7),align = "h")

ggdraw() +
  draw_plot(fig)




#Oldest papers
View(table(ArticlesTable$Publication_Year))
#oldest paper is 1975
ArticlesTable$Topic[ArticlesTable$Publication_Year=="1975"]
#topic for the 1975 paper is "glue secretion"
ArticlesTable$Topic[ArticlesTable$Publication_Year=="1976"]
#topic for the 1976 paper is "glue gene identification"

ArticlesTable$Publication_Year[ArticlesTable$Topic=="glue ultrastructure and adhesion"]
#articles published in 2019 2020 2021
#"three papers focusing on Drosophila glue ultrastructure and adhesive properties, published in 2019-2021"

